summaryrefslogtreecommitdiffhomepage
path: root/test/scenario_test/route_server_test.py
diff options
context:
space:
mode:
authorHiroshi Yokoi <yokoi.hiroshi@po.ntts.co.jp>2015-01-15 15:59:16 +0900
committerFUJITA Tomonori <fujita.tomonori@lab.ntt.co.jp>2015-01-15 19:52:05 +0900
commitd2d88bfb929d40e788def9ce85749dbc85d0f02f (patch)
tree6c8f054aec4685c95ed7137a628a7e6ca6be9a4c /test/scenario_test/route_server_test.py
parent8bcc2c0d768abe7232bf9d47e5c2ef733d0f9d65 (diff)
scenario_test: made small changes
Signed-off-by: FUJITA Tomonori <fujita.tomonori@lab.ntt.co.jp>
Diffstat (limited to 'test/scenario_test/route_server_test.py')
-rw-r--r--test/scenario_test/route_server_test.py24
1 files changed, 12 insertions, 12 deletions
diff --git a/test/scenario_test/route_server_test.py b/test/scenario_test/route_server_test.py
index 9b9b1991..8915d8f8 100644
--- a/test/scenario_test/route_server_test.py
+++ b/test/scenario_test/route_server_test.py
@@ -214,25 +214,25 @@ class GoBGPTest(unittest.TestCase):
exist_n += 1
self.assertEqual(exist_n, 1)
- def test_07_active_when_depend_quagga(self):
- print "test_active_when_depend_quagga"
+ def test_07_active_when_quagga_removed(self):
+ print "test_active_when_removed_quagga"
# remove quagga container
- fab.docker_container_depend(self.deleting_quagga)
- depend_quagga_address = "10.0.0." + str(self.deleting_quagga)
+ fab.docker_container_removed(self.deleting_quagga)
+ removed_quagga_address = "10.0.0." + str(self.deleting_quagga)
- # get neighbor state and remote ip of depend quagga
- print "check of [" + depend_quagga_address + " ]"
- url = "http://" + self.gobgp_ip + ":" + self.gobgp_port + "/v1/bgp/neighbor/" + depend_quagga_address
+ # get neighbor state and remote ip of removed quagga
+ print "check of [" + removed_quagga_address + " ]"
+ url = "http://" + self.gobgp_ip + ":" + self.gobgp_port + "/v1/bgp/neighbor/" + removed_quagga_address
r = requests.get(url)
neighbor = json.loads(r.text)
state = neighbor['info']['bgp_state']
remote_ip = neighbor['conf']['remote_ip']
- self.assertEqual(depend_quagga_address, remote_ip)
+ self.assertEqual(removed_quagga_address, remote_ip)
self.assertEqual(state, "BGP_FSM_ACTIVE")
- def test_08_received_route_when_depend_quagga(self):
- print "test_received_route_when_depend_quagga"
+ def test_08_received_route_when_quagga_removed(self):
+ print "test_received_route_when_removed_quagga"
if self.check_load_config() is False:
return
@@ -269,8 +269,8 @@ class GoBGPTest(unittest.TestCase):
exist_n += 1
self.assertEqual(exist_n, 1)
- def test_09_advertising_route_when_depend_quagga(self):
- print "test_advertising_route_when_depend_quagga"
+ def test_09_advertising_route_when_quagga_removed(self):
+ print "test_advertising_route_when_removed_quagga"
if self.check_load_config() is False:
return